#[repr(u8)]pub enum Flashdqsopt {
Val0 = 0,
Val1 = 1,
}Variants
Val0 = 0
FlexSPI drives toggling SCLK output until it receives all flash read data bits. There will be an extra SCLK cycle after all read data bits are returned on SPI bus.
Val1 = 1
FlexSPI drives SCLK output according to read data size and pad number (no extra SCLK toggling). If there is DQS latency, FlexSPI receives less data than required. Never set this bit if there is DQS latency.
Implementations
Sourceimpl Flashdqsopt
impl Flashdqsopt