#[repr(u8)]pub enum Wmopt1b {
Val0 = 0,
Val1 = 1,
}Variants
Val0 = 0
DQSB used as Write Mask when writing to external device.
Val1 = 1
DQSB not used as Write Mask when writing to external device.
Implementations