#[repr(u8)]pub enum Wmopt2b {
Val0 = 0,
Val1 = 1,
}Variants
Val0 = 0
DQSB is used as Write Mask when writing to external device.
Val1 = 1
DQSB is not used as Write Mask when writing to external device.
Implementations